##*****************************************************************************
#  AUTHOR:
#    Michael Hinton <hinton@schedmd.com>
#    Grzegorz Andrejczuk <grzegorza@graphcore.ai>
#
#  SYNOPSIS:
#    X_AC_VIPU
#
#  DESCRIPTION:
#    Determine if Graphcore V-IPU Client library is present
##*****************************************************************************


AC_DEFUN([X_AC_VIPU],
[
  func_check_path ()
  {
      AC_CHECK_HEADER([vipu_client.h], [ac_vipu_client_h=yes], [ac_vipu_client_h=no])
      AC_CHECK_LIB([vipulib], [vipu_init], [ac_vipulib=yes], [ac_vipulib=no])
  }

  _x_ac_vipu_dirs="/usr/local /usr /opt/vipu_lib /opt"
  _x_ac_vipu_libs="lib lib64"

  AC_ARG_WITH(
    [vipu],
    AS_HELP_STRING(--with-vipu=PATH, Specify path to V-IPU installation),
    [AS_IF([test "x$with_vipu" != xno && test "x$with_vipu" != xyes],
           [_x_ac_vipu_dirs="$with_vipu"])])

  if [test "x$with_vipu" = xno]; then
     AC_MSG_WARN([support for V-IPU disabled])
  else

    # Check if libvipulib is already in the system paths
    func_check_path

    if [ test "$ac_vipulib" = "yes" && test "$ac_vipu_client_h" = "yes" ]; then
          # found in system path
          AC_MSG_NOTICE([Found in system path])
          vipu_includes=""
          vipu_libs="-lvipulib"
    else
      #try to find libvipulib
      for d in $_x_ac_vipu_dirs; do
        if [ ! test -d "$d" ]; then
          continue
        fi
        for bit in $_x_ac_vipu_libs; do
          if [ ! test -d "$d/$bit" || ! test -d "$d/include" ]; then
            continue
          fi
          _x_ac_vipu_ldflags_save="$LDFLAGS"
          _x_ac_vipu_cppflags_save="$CPPFLAGS"
          LDFLAGS="-L$d/$bit -lvipulib"
          CPPFLAGS="-I$d/include $CPPFLAGS"
          $as_unset ac_cv_header_vipu_h
          $as_unset ac_cv_lib_vipulib_vipu_init

          AC_MSG_NOTICE([Testing $d $bit])

          func_check_path

          LDFLAGS="$_x_ac_vipu_ldflags_save"
          CPPFLAGS="$_x_ac_vipu_cppflags_save"
          if [ test "$ac_vipulib" = "yes" && test "$ac_vipu_client_h" = "yes" ]; then
            vipu_includes="-I$d/include"
            vipu_libs="-L$d/$bit -lvipulib"
            break
          fi
        done
        if [ test "$ac_vipulib" = "yes" && test "$ac_vipu_client_h" = "yes" ]; then
          break
        fi
      done
    fi

    if [ test "$ac_vipulib" = "yes" && test "$ac_vipu_client_h" = "yes" ]; then
      VIPU_LIBS="$vipu_libs"
      VIPU_CPPFLAGS="$vipu_includes"
      AC_DEFINE(HAVE_VIPU, 1, [Define to 1 if V-IPU library found])
    else
      if test -z "$with_vipu"; then
        AC_MSG_WARN([unable to locate libvipulib.so and/or vipu_client.h])
      else
        AC_MSG_ERROR([unable to locate libvipulib.so and/or vipu_client.h])
      fi
    fi

    AC_SUBST(VIPU_LIBS)
    AC_SUBST(VIPU_CPPFLAGS)
  fi
  AM_CONDITIONAL(HAVE_VIPU, test "$ac_vipulib" = "yes" && test "$ac_vipu_client_h" = "yes")
])
