#ifndef __SLURM_VIPU_H__
#define __SLURM_VIPU_H__

#include "src/common/slurm_xlator.h"
#include "xstring.h"
#include "slurm/slurm.h"

#include <stdint.h>

/*
 * Generate partition id from job id.
 * Partition id is needed to interfere with
 * partition manager.
 */
extern char *vipu_p_partition_name(uint32_t job_id);

/*
 * Get list Vipu configs or base names of vipu configuration files.
 * It will seek config files in slurm configuration directory and return
 * configs with name.vipu.conf
 */
extern List vipu_p_get_configs(void);

/*
 * Validate IPU job.
 */
extern int validate_ipu_job_for_config(const char *config, unsigned num_ipus);

/*
 * Creates partition with name obtainable by vipu_p_partition_name(job_id)
 * @config - name from vipu_p_get_configs
 * @num_ipus - number of IPUs
 * @num_replical - number of replicas (0 means no replicas)
 * @job_id - Job ID TODO: Check if it works with slurmd
 * @num_tasks - number of tasks and current code will create 1 GCD per task.
 * Returns:
 * SLURM_SUCCESS and SLURM_ERROR when failed
 */
extern int vipu_p_create_partition(const char *config, unsigned num_ipus, unsigned num_replicas, unsigned job_id, unsigned num_tasks);

/*
 * Destroys partition
 * @partition_name - name
 * @config - config
 * Returns:
 * SLURM_SUCCESS and SLURM_ERROR when failed
 */
extern int vipu_p_destroy_partition(const char *partition_name, const char *config);

/*
 * Checks if partition is active
 * @partition_name - name
 * @config - config
 * Returns:
 * SLURM_SUCCESS and SLURM_ERROR when failed
 */
extern int vipu_p_is_partition_active(const char *partition_name, const char *config);

/*
 * In case of multi GCD prepare multiple configs
 * @partition_name - name
 * @config - config
 * Returns:
 * SLURM_SUCCESS and SLURM_ERROR when failed
 */
extern int vipu_p_copy_ipuof_configs(const char *partition_name, const char *config);


#endif /* __SLURM_VIPU_H__ */
