/*****************************************************************************\
 * Copyright (c) 2021-2022 Graphcore Ltd.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 *
 * This file is part of the modified version of Slurm, a resource management
 * program with Graphcore IPU support. The modified version includes a new
 * resource selection plugin, vipu, as well as a new job submission plugin,
 * vipu, with the support handling IPU jobs.
 *
 * Please also read the included files: README, DISCLAIMER and COPYING.
 *
 * The modified Slurm source code is modified and redistributed under the terms
 * of the GNU General Public License version 3 (GPL v3) as published by the
 * Free Software Foundation.
 *
\*****************************************************************************/

#ifndef _GRAPHCORE_VIPULIB_VIPU_C_CLIENT_H
#define _GRAPHCORE_VIPULIB_VIPU_C_CLIENT_H

/*
 * C Wrapper for VipuClient
 */

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
namespace graphcore {
namespace vipulib {
#endif

typedef enum PartitionState {
	PS_UNDEFINED = 0,
	PS_PENDING = 1,
	PS_ACTIVE = 2,
	PS_REMOVED = 3,
	PS_ERROR = 4
} partition_state_t;

typedef struct VipuClient VipuClient;

VipuClient *vipu_init(const char *host, uint32_t port, uint32_t timeout);

VipuClient *vipu_init_secure(const char *host, uint32_t port, uint32_t timeout,
			     const char *client_cert, const char *client_key,
			     const char *server_cert, const char *user_id,
			     const char *access_key);
int vipu_create_partition(VipuClient *c, const char *partition_id,
			 uint32_t size, char *ipuof_config_json);
int vipu_create_partition_on_cluster(VipuClient *c, const char *partition_id,
				     uint32_t size, const char *cluster_id,
				     char *ipuof_config_json);
int vipu_create_partition_with_details(VipuClient *c, const char *partition_id,
				       uint32_t size, const char *cluster_id,
				       uint32_t num_ipulink_segments,
				       uint32_t num_gcds, uint32_t reconfigurable,
				       uint32_t num_replicas, char *ipuof_config_json);

char **vipu_get_ipuof_config(VipuClient *c, const char *partition_id,
				uint32_t *num_gcds);

int vipu_remove_partition(VipuClient *c, const char *partition_id);

int vipu_remove_partition_force(VipuClient *c, const char *partition_id);

int vipu_reset_partition(VipuClient *c, const char *partition_id);

char **vipu_list_partitions(VipuClient *c, uint32_t *num_partitions);

int vipu_get_partition_status(VipuClient *c, const char *partition_id,
			      partition_state_t *state);

void vipu_destroy(VipuClient *c);

#ifdef __cplusplus
} // namespace vipulib
} // namespace graphcore
} // extern "C"
#endif

#endif // _GRAPHCORE_VIPULIB_VIPU_C_CLIENT_H
