/*****************************************************************************\
 * Copyright (c) 2021-2022 Graphcore Ltd.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 *
 * This file is part of the modified version of Slurm, a resource management
 * program with Graphcore IPU support. The modified version includes a new
 * resource selection plugin, vipu, as well as a new job submission plugin,
 * vipu, with the support handling IPU jobs.
 *
 * Please also read the included files: README, DISCLAIMER and COPYING.
 *
 * The modified Slurm source code is modified and redistributed under the terms
 * of the GNU General Public License version 3 (GPL v3) as published by the
 * Free Software Foundation.
 *
\*****************************************************************************/

/*****************************************************************************\
 * config.h
 * Configuration handling for the Resource selection plugin with VIPU support
 *****************************************************************************/

#ifndef _SELECT_VIPU_CONFIG_H
#define _SELECT_VIPU_CONFIG_H

#include <stdint.h>

#define DEFAULT_PORT 8090
#define DEFAULT_SECURE 0
#define DEFAULT_CLIENT_CERT_FILE "/etc/slurm/vipu_certs/client.cert"
#define DEFAULT_SERVER_CERT_FILE "/etc/slurm/vipu_certs/server.cert"
#define DEFAULT_CLIENT_KEY_FILE "/etc/slurm/vipu_certs/client.key"
// Prevent define collision
#define _DEFAULT_IPUOF_DIR "/data"
#define DEFAULT_TIMEOUT 60
#define DEFAULT_MAX_IPUS_PER_JOB 256
#define DEFAULT_FORCE_DELETE_PARTITION 0
#define DEFAULT_USE_RECONFIG_PARTITION 0

typedef struct vipu_select_config
{
	char *model;                     /* VIPU GRES model */
	char *host;                      /* VIPU API Host */
	uint16_t port;                   /* VIPU API Port */
	uint16_t secure;                 /* Is Secure access is required? */
	char *user;                      /* VIPU API User */
	char *accesskey;                 /* VIPU API access key */
	char *client_cert_file;          /* Client key file */
	char *client_key_file;           /* Client SSL cert file */
	char *server_cert_file;          /* Server SSL cert file */
	char *ipuof_dir;                 /* IPUoF directory on the nodes */
	uint32_t max_ipus_per_job;       /* Maximum IPUs per job */
	uint32_t timeout;                /* Client timeout */
	uint32_t hash_val;               /* Hash val */
	uint16_t force_delete_partition; /* Specifies whether partitions should be force deleted or not */
	uint16_t use_reconfig_partition; /* Specifies whether reconfiguration partitions should be used */
	} vipu_select_config_t;

typedef struct vipu_config_data
{
	vipu_select_config_t vipu_conf;
	s_p_hashtbl_t *vipu_conf_hashtbl;
	vipu_select_config_t *vipu_conf_ptr;
	bool vipu_conf_initialized;
} vipu_config_data_t;

extern char *default_vipu_config;

extern vipu_config_data_t *vipu_conf_init(const char *path);
extern int vipu_conf_destroy(vipu_config_data_t *conf);

extern char *vipu_conf_get_model(vipu_config_data_t *conf);
extern char *vipu_conf_get_host(vipu_config_data_t *conf);
extern char *vipu_conf_get_user(vipu_config_data_t *conf);
extern char *vipu_conf_get_accesskey(vipu_config_data_t *conf);
extern char *vipu_conf_get_client_cert_file(vipu_config_data_t *conf);
extern char *vipu_conf_get_client_key_file(vipu_config_data_t *conf);
extern char *vipu_conf_get_server_cert_file(vipu_config_data_t *conf);
extern char *vipu_conf_get_ipuof_dir(vipu_config_data_t *conf);
extern uint16_t vipu_conf_get_port(vipu_config_data_t *conf);
extern uint16_t vipu_conf_get_secure(vipu_config_data_t *conf);
extern uint32_t vipu_conf_get_max_ipus_per_job(vipu_config_data_t *conf);
extern uint32_t vipu_conf_get_timeout(vipu_config_data_t *conf);
extern uint16_t vipu_conf_get_force_delete_partition(vipu_config_data_t *conf);
extern uint16_t vipu_conf_get_use_reconfig_partition(vipu_config_data_t *conf);

#endif /* !_SELECT_VIPU_CONFIG_H */
