/*****************************************************************************\
 * Copyright (c) 2021-2022 Graphcore Ltd.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 *
 * This file is part of the modified version of Slurm, a resource management
 * program with Graphcore IPU support. The modified version includes a new
 * resource selection plugin, vipu, as well as a new job submission plugin,
 * vipu, with the support handling IPU jobs.
 *
 * Please also read the included files: README, DISCLAIMER and COPYING.
 *
 * The modified Slurm source code is modified and redistributed under the terms
 * of the GNU General Public License version 3 (GPL v3) as published by the
 * Free Software Foundation.
 *
\*****************************************************************************/

/*****************************************************************************\
 * job_submit_vipu.c - Job submit plugin with VIPU support.
 *****************************************************************************/

#include <inttypes.h>
#include <stdio.h>
#include <string.h>
#include <sys/types.h>
#include <stdlib.h>
#include <unistd.h>

#include "src/common/slurm_xlator.h"
#include "src/slurmctld/slurmctld.h"
#include "slurm/slurm_errno.h"
#include "src/common/gres.h"

#define _DEBUG 1

/*
 * These variables are required by the generic plugin interface.  If they
 * are not gres_token in the plugin, the plugin loader will ignore it.
 *
 * plugin_name - a string giving a human-readable description of the
 * plugin.  There is no maximum length, but the symbol must refer to
 * a valid string.
 *
 * plugin_type - a string suggesting the type of the plugin or its
 * applicability to a particular form of data or method of data handling.
 * If the low-level plugin API is used, the contents of this string are
 * unimportant and may be anything.  Slurm uses the higher-level plugin
 * interface which requires this string to be of the form
 *
 *	<application>/<method>
 *
 * where <application> is a description of the intended application of
 * the plugin (e.g., "auth" for Slurm authentication) and <method> is a
 * description of how this plugin satisfies that application.  Slurm will
 * only load authentication plugins if the plugin_type string has a prefix
 * of "auth/".
 *
 * plugin_version - an unsigned 32-bit integer containing the Slurm version
 * (major.minor.micro combined into a single number).
 */
const char plugin_name[] = "Job submit vipu plugin";
const char plugin_type[] = "job_submit/vipu";
const uint32_t plugin_version = SLURM_VERSION_NUMBER;

int init(void)
{
	info("job_submit_vipu: job submit plugin loaded");
	info("%s: THIS PLUGIN WILL BE REMOVED IN FUTURE RELEASE", plugin_type);
	info("%s: Please update your configuration", plugin_type);
	return SLURM_SUCCESS;
}

int fini(void)
{
	return SLURM_SUCCESS;
}

extern int job_submit(job_desc_msg_t *job_desc, uint32_t submit_uid)
{
	debug("%s: job submit plugin: tres_per_job = %s tres_per_node = %s",
	      plugin_type, job_desc->tres_per_job, job_desc->tres_per_node);
	return SLURM_SUCCESS;
}

extern int job_modify(job_desc_msg_t *job_desc, job_record_t *job_ptr,
		      uint32_t submit_uid)
{
	return SLURM_SUCCESS;
}
